pub fn from_slice_escaped<'a, T>(
v: &'a [u8],
string_unescape_buffer: &mut [u8],
) -> Result<(T, usize)>where
T: Deserialize<'a>,Expand description
Deserializes an instance of type T from bytes of JSON text, using the provided buffer to unescape strings
Returns the value and the number of bytes consumed in the process